@@ -36,29 +36,78 @@ class FhirToAttributeDict:
         address: Optional[AddressType] = FhirToAttributeDict.get_address(
             resource.address
         )
+
         # https://github.com/GreenBuildingRegistry/usaddress-scourgify
         # noinspection PyUnresolvedReferences
-        address_formatted: Optional[Mapping[str, str]] = (
-            FhirToAttributeDict.safe_normalize_address_record(
-                {
-                    "address_line_1": address.line[0]
-                    if address.line and len(address.line) > 0
-                    else None,
-                    "address_line_2": address.line[1]
-                    if address.line and len(address.line) > 1
-                    else None,
-                    "city": address.city if address.city else None,
-                    "state": address.state if address.state else None,
-                    "postal_code": address.postalCode if address.postalCode else None,
-                }
-            )
+        address_dict = (
+            {
+                "address_line_1": address.line[0]
+                if address.line and len(address.line) > 0
+                else None,
+                "address_line_2": None,
+                # "address_line_2": address.line[1]
+                # if address.line and len(address.line) > 1
+                # else None,
+                "city": address.city if address.city else None,
+                "state": address.state if address.state else None,
+                "postal_code": address.postalCode[0:5]
+                if address.postalCode and len(address.postalCode) >= 5
+                else None,
+            }
             if address
             else None
         )
+
+        combined_address = (
+            f"{address_dict['address_line_1'] or ''} "
+            f"{address_dict['address_line_2'] or ''} "
+            f"{address_dict['city']} {address_dict['state']} {address_dict['postal_code']}"
+            if address_dict
+            else None
+        )
+
+        # parsed_address, parsed_address_type = FhirToAttributeDict.safe_tag_address(
+        #     combined_address,
+        #     tag_mapping={
+        #         'Recipient': 'recipient',
+        #         'AddressNumber': 'address_line_1',
+        #         'AddressNumberPrefix': 'address_line_1',
+        #         'AddressNumberSuffix': 'address_line_1',
+        #         'StreetName': 'address_line_1',
+        #         'StreetNamePreDirectional': 'address_line_1',
+        #         'StreetNamePreModifier': 'address_line_1',
+        #         'StreetNamePreType': 'address_line_1',
+        #         'StreetNamePostDirectional': 'address_line_1',
+        #         'StreetNamePostModifier': 'address_line_1',
+        #         'StreetNamePostType': 'address_line_1',
+        #         'CornerOf': 'address_line_1',
+        #         'IntersectionSeparator': 'address_line_1',
+        #         'LandmarkName': 'address_line_1',
+        #         'USPSBoxGroupID': 'address_line_1',
+        #         'USPSBoxGroupType': 'address_line_1',
+        #         'USPSBoxID': 'address_line_1',
+        #         'USPSBoxType': 'address_line_1',
+        #         'BuildingName': 'address_line_2',
+        #         'OccupancyType': 'address_line_2',
+        #         'OccupancyIdentifier': 'address_line_2',
+        #         'SubaddressIdentifier': 'address_line_2',
+        #         'SubaddressType': 'address_line_2',
+        #         'PlaceName': 'city',
+        #         'StateName': 'state',
+        #         'ZipCode': 'postal_code',
+        #     }
+        # )
+        #
+        address_formatted: Optional[Mapping[str, str]] = (
+            FhirToAttributeDict.safe_normalize_address_record(address_dict)
+            if address_dict
+            else None
+        )
+
         # https://github.com/datamade/usaddress
         # noinspection PyUnresolvedReferences
         address_tagged, address_type = (
-            (FhirToAttributeDict.safe_tag_address(address.line[0]))
+            (FhirToAttributeDict.safe_tag_address(combined_address))
             if address and address.line and len(address.line) > 0
             else (None, None)
         )
@@ -90,6 +139,31 @@ class FhirToAttributeDict:
 
         age_in_years = FhirToAttributeDict.calculate_age_in_years(resource.birthDate)
 
+        # noinspection PyUnresolvedReferences
+        address_postal_code = (
+            address_formatted.get("postal_code")
+            if address_formatted
+            else address.postalCode
+            if address and address.postalCode
+            else None
+        )
+
+        # noinspection PyUnresolvedReferences
+        address_line_1 = (
+            address_formatted.get("address_line_1")
+            if address_formatted
+            else address.line[0]
+            if address and address.line and len(address.line) > 0
+            else None
+        )
+
+        # noinspection PyUnresolvedReferences
+        name_middle = (
+            patient_name.given[1]
+            if patient_name and patient_name.given and len(patient_name.given) > 1
+            else None
+        )
+
         # noinspection PyUnresolvedReferences
         scoring_input: ScoringInput = ScoringInput(
             id_=resource.id,
@@ -97,16 +171,19 @@ class FhirToAttributeDict:
             if patient_name and patient_name.given and len(patient_name.given) > 0
             else None,
             name_family=patient_name.family if patient_name else None,
+            name_middle=name_middle,
+            name_middle_initial=name_middle[0]
+            if name_middle and len(name_middle) > 0
+            else None,
             gender=resource.gender,
             birth_date=resource.birthDate.strftime("%Y-%m-%d")
             if resource.birthDate
             else None,
-            address_postal_code=address_formatted.get("postal_code")
-            if address_formatted
-            else None,
-            address_line_1=address_formatted.get("address_line_1")
-            if address_formatted
+            address_postal_code=address_postal_code,
+            address_postal_code_first_five=address_postal_code[0:5]
+            if address_postal_code and len(address_postal_code) >= 5
             else None,
+            address_line_1=address_line_1,
             email=email,
             phone=phone_clean,
             birth_date_year=str(resource.birthDate.year)
@@ -125,6 +202,7 @@ class FhirToAttributeDict:
             email_username=email_user_name,
             is_adult_today=age_in_years >= 18 if age_in_years else None,
             ssn=ssn,
+            ssn_last4=ssn[-4] if ssn and len(ssn) >= 4 else None,
             meta_security_client_slug=meta_security_code,
         )
         return scoring_input
@@ -135,23 +213,36 @@ class FhirToAttributeDict:
     ) -> Mapping[str, str]:
         try:
             return cast(Mapping[str, str], normalize_address_record(address=address))
+        # except UnParseableAddressError:
+        #     # regular expressions to find po box and zip code
+        #     zipexpr = re.compile(r'\d{5}(-?\d{4})?$')
+        #     boxexpr = re.compile(r'^P\.?O\.?\s?box (\d+)', flags=re.IGNORECASE)
+        #     address_line_1 = address["address_line_1"]
+        #     if 'POBOX' in address_line_1.upper().replace('.', ''):
+        #         pobox = re.search(boxexpr, address_line_1)[0]
+        #
+        #         address['address_line_1'] = pobox.upper()
+        #
+        #         return cast(Mapping[str, str], normalize_address_record(address=address))
+        #     else:
+        #         raise
         except Exception as e:
-            print(f"PersonMatching Error: Standardizing Address: {e}")
+            print(f"PersonMatching Error: Standardizing Address: {address!r} {e}")
             # Handle this exception gracefully,
             #  returning address object 'as is' and not normalized.
             return cast(Mapping[str, str], address)
 
     @staticmethod
     def safe_tag_address(
-        address_line: Optional[str],
+        address_line: Optional[str], tag_mapping: Optional[Mapping[str, str]] = None
     ) -> Tuple[OrderedDict[str, Union[List[Any], str]], str]:
         try:
             return cast(
                 Tuple[OrderedDict[str, Union[List[Any], str]], str],
-                usaddress.tag(address_line),
+                usaddress.tag(address_line, tag_mapping=tag_mapping),
             )
         except Exception as e:
-            print(f"PersonMatching Error: Tagging Address: {e}")
+            print(f"PersonMatching Error: Tagging Address: {address_line} {e}")
             tagged_address = OrderedDict[str, Union[List[Any], str]]()
             return tagged_address, "Ambiguous"
 
