@@ -1,10 +1,12 @@
 from dataclasses import dataclass
 from typing import Optional
 
+from helix_personmatching.models.attribute_entry import AttributeEntry
+
 
 @dataclass
 class RuleAttributeScore:
-    attribute: str
+    attribute: AttributeEntry
     score: float
     present: bool
     source: Optional[str]
