@@ -3,6 +3,7 @@ import json
 from pathlib import Path
 from typing import List
 
+
 from helix_personmatching.logics.match_score import MatchScore
 from helix_personmatching.matchers.matcher import Matcher
 
@@ -27,7 +28,7 @@ def test_exact_match() -> None:
     score = scores[0]
     assert score.matched is True
 
-    assert score.total_score == 94.56845238095238
+    assert score.total_score > 0.995
 
     score_dict = dataclasses.asdict(score)
 
