@@ -27,7 +27,7 @@ def test_exact_match_list() -> None:
     score = scores[0]
     assert score.matched is True
 
-    assert score.total_score == 94.56845238095238
+    assert score.total_score > 0.995
 
     score_dict = dataclasses.asdict(score)
 
