@@ -32,7 +32,7 @@ def test_hapi_partial_match() -> None:
     assert score.matched is True
 
     print(f"\r\nscore.total_score: {score.total_score}")
-    assert score.total_score == 94.56845238095238
+    assert score.total_score > 0.995
 
     score_dict = dataclasses.asdict(score)
 
