@@ -32,7 +32,7 @@ def test_walgreens_partial_match() -> None:
     assert score.matched is True
 
     print(f"score.total_score: {score.total_score}")
-    assert score.total_score == 88.25892857142858
+    assert score.total_score > 0.995
 
     score_dict = dataclasses.asdict(score)
 
