@@ -5,6 +5,7 @@ from typing import List
 
 from helix_personmatching.logics.match_score import MatchScore
 from helix_personmatching.matchers.matcher import Matcher
+from helix_personmatching.models.rules.RuleWeight import RuleWeight
 from helix_personmatching.models.scoring_option import ScoringOption
 
 
@@ -24,7 +25,9 @@ def test_walgreens_partial_match_with_extra_rule() -> None:
         source_json=walgreens_person_json,
         target_json=bwell_master_person_json,
         verbose=True,
-        options=[ScoringOption(rule_name="Rule-050", weight=1.0)],
+        options=[
+            ScoringOption(rule_name="Rule-050", weight=RuleWeight.get_standard_weight())
+        ],
     )
 
     assert len(scores) == 1
@@ -34,7 +37,7 @@ def test_walgreens_partial_match_with_extra_rule() -> None:
     assert score.matched is True
 
     print(f"score.total_score: {score.total_score}")
-    assert score.total_score == 94.50892857142858
+    assert score.total_score > 0.995
 
     score_dict = dataclasses.asdict(score)
 
