@@ -1,3 +1,4 @@
+import dataclasses
 import json
 from datetime import datetime, date
 from typing import Any
@@ -14,3 +15,12 @@ def json_serializer(obj: Any) -> str:
     if hasattr(obj, "__dict__"):
         return json.dumps(obj.__dict__, default=json_serializer)
     return str(obj)
+
+
+class EnhancedJSONEncoder(json.JSONEncoder):
+    def default(self, o: Any) -> Any:
+        if dataclasses.is_dataclass(o):
+            return dataclasses.asdict(o)
+        if isinstance(o, (datetime, date)):
+            return o.isoformat()
+        return super().default(o)
